@@ -532,7 +532,7 @@ plot.tuts_poisBFS = function(x, type, ...) {
     graphics::lines(y=PRED.MED,x=ti.sim,type='l',col='blue',lwd=1,lty=1)
     graphics::lines(y=PRED.UPR,x=ti.sim,type='l',col='blue',lwd=1,lty=2)
 
-    graphics::legend("topright",legend = c("Observed","Upper CI","Medium","Lower CI"),
+    graphics::legend("topright",legend = c("Observed","Upper CI","Median","Lower CI"),
            col=c("black","blue","blue","blue"),lwd=c(2,1,1,1),lty=c(1,2,1,2))
   }
   #
@@ -667,7 +667,7 @@ plot.tuts_poisBFS = function(x, type, ...) {
     graphics::lines(y=lambda.lwr,x=ti.sim,type='l',col='blue',lwd=1,lty=2)
     graphics::lines(y=lambda.upr,x=ti.sim,type='l',col='blue',lwd=1,lty=2)
 
-    graphics::legend("topright",legend = c("Upper CI","Medium","Lower CI"),
+    graphics::legend("topright",legend = c("Upper CI","Median","Lower CI"),
            col=c("blue","black","blue"),lwd=c(1,1,1),lty=c(2,1,2))
 
 
